#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""Universal Calibration Protocol for Python"""
from .master import Master
from .transport import Can
from .transport import Eth
from .transport import SxI
from .transport import Usb


__copyright__ = """
    pySART - Simplified AUTOSAR-Toolkit for Python.

   (C) 2009-2019 by Christoph Schueler <cpu12.gems@googlemail.com>

   All Rights Reserved

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
"""

# if you update this manually, do not forget to update .bumpversion.cfg
__version__ = "0.18.18"



from collections import namedtuple

import rekorder as rec

XcpLogFileHeader = namedtuple(
    "XcpLogFileHeader",
    "record_count size_uncompressed size_compressed compression_ratio",
)


class XcpLogFileReader:
    """ """

    def __init__(self, file_name):
        self._reader = rec._XcpLogFileReader(file_name)

    def get_header(self):
        return XcpLogFileHeader(*self._reader.get_header())

    def reset_iter(self):
        self._reader.reset()

    def __iter__(self):
        while True:
            frames = self._reader.next()
            if frames is None:
                break
            for category, counter, timestamp, length, payload in frames:
                yield (category, counter, timestamp, payload)


class XcpLogFileWriter:
    """ """

    def __init__(self, file_name):
        self._writer = rec._XcpLogFileWriter(file_name)


print("Before c-tor()")
reader = XcpLogFileReader("test_logger")
print("After c-tor()")
hdr = reader.get_header()
print(hdr)

for frame in reader:
    # print(frame)
    pass

print("Finished.")
